"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UnityChangeset = void 0;
const REGEXP_HUB_LINK = /^unityhub:\/\/(\d{4}\.\d+\.\d+(a|b|f)\d+)\/(\w{12})$/;
const REGEXP_UNITY = /^(\d+)\.(\d+)\.(\d+)([a-zA-Z]+)(\d+)/;
const REGEXP_UNITY_NUM = /^(\d+)\.?(\d+)?\.?(\d+)?([a-zA-Z]+)?(\d+)?/;
class UnityChangeset {
    constructor(version, changeset) {
        this.version = '';
        this.changeset = '';
        this.versionNumber = 0;
        this.minor = '';
        this.lifecycle = '';
        this.toString = () => {
            return `${this.version}\t${this.changeset}`;
        };
        Object.assign(this, { version, changeset });
        const match = this.version.match(REGEXP_UNITY);
        if (match) {
            this.versionNumber = UnityChangeset.toNumber(this.version, false);
            this.minor = `${match[1]}.${match[2]}`;
            this.lifecycle = `${match[4]}`;
        }
    }
}
exports.UnityChangeset = UnityChangeset;
UnityChangeset.isValid = (href) => {
    return REGEXP_HUB_LINK.test(href);
};
UnityChangeset.createFromHref = (href) => {
    const match = href.match(REGEXP_HUB_LINK);
    return new UnityChangeset(match === null || match === void 0 ? void 0 : match[1], match === null || match === void 0 ? void 0 : match[3]);
};
UnityChangeset.toNumber = (version, max) => {
    const match = version.toString().match(REGEXP_UNITY_NUM);
    if (match === null)
        return 0;
    return parseInt(match[1] || (max ? '9999' : '0')) * 100 * 100 * 100 * 100
        + parseInt(match[2] || (max ? '99' : '0')) * 100 * 100 * 100
        + parseInt(match[3] || (max ? '99' : '0')) * 100 * 100
        + ((match[4] || (max ? 'z' : 'a')).toUpperCase().charCodeAt(0) - 65) * 100
        + parseInt(match[5] || (max ? '99' : '0'));
};
//# sourceMappingURL=unityChangeset.js.map